merge
authorBrendan O'Dea <bod@optus.net>
Sat, 30 Oct 2004 07:17:41 +0000 (07:17 +0000)
committerBrendan O'Dea <bod@optus.net>
Sat, 30 Oct 2004 07:17:41 +0000 (07:17 +0000)
l2tpns.c
l2tpns.h

index a08bd5c..6bd3af7 100644 (file)
--- a/l2tpns.h
+++ b/l2tpns.h
@@ -1,5 +1,5 @@
 // L2TPNS Global Stuff
-// $Id: l2tpns.h,v 1.24 2004-10-29 04:01:11 bodea Exp $
+// $Id: l2tpns.h,v 1.25 2004-10-30 07:17:41 bodea Exp $
 
 #ifndef __L2TPNS_H__
 #define __L2TPNS_H__
@@ -40,7 +40,7 @@
 #define MAX_LOG_LENGTH 512             // Maximum size of log message
 #define ECHO_TIMEOUT   60              // Time between last packet sent and LCP ECHO generation
 #define IDLE_TIMEOUT   240             // Time between last packet sent and LCP ECHO generation
-#define BUSY_WAIT_TIMEOUT      3000    // 5 minutes in 1/10th seconds to wait for radius to cleanup on shutdown
+#define BUSY_WAIT_TIME 3000            // 5 minutes in 1/10th seconds to wait for radius to cleanup on shutdown
 
 // Constants
 #ifndef ETCDIR
@@ -497,17 +497,6 @@ void radiusretry(u16 r);
 u16 radiusnew(sessionidt s);
 void radiusclear(u16 r, sessionidt s);
 
-// throttle.c
-int throttle_session(sessionidt s, int throttle);
-
-
-// rl.c
-void init_rl();
-u16 rl_create_tbf();
-u16 rl_get_tbf();
-void rl_done_tbf(u16 t);
-void rl_destroy_tbf(u16 t);
-
 
 // l2tpns.c
 clockt now(void);
--- a/l2tpns.c
+++ b/l2tpns.c
@@ -4,7 +4,7 @@
 // Copyright (c) 2002 FireBrick (Andrews & Arnold Ltd / Watchfront Ltd) - GPL licenced
 // vim: sw=8 ts=8
 
-char const *cvs_id_l2tpns = "$Id: l2tpns.c,v 1.35 2004-10-30 06:58:55 bodea Exp $";
+char const *cvs_id_l2tpns = "$Id: l2tpns.c,v 1.36 2004-10-30 07:17:41 bodea Exp $";
 
 #include <arpa/inet.h>
 #include <assert.h>
@@ -2221,8 +2221,8 @@ int still_busy(void)
                return 1;
        }
 
-       // We stop waiting for radius after BUSY_WAIT_TIMEOUT 1/10th seconds
-       if (abs(TIME - start_busy_wait) > BUSY_WAIT_TIMEOUT)
+       // We stop waiting for radius after BUSY_WAIT_TIME 1/10th seconds
+       if (abs(TIME - start_busy_wait) > BUSY_WAIT_TIME)
        {
                log(1, 0, 0, 0, "Giving up waiting for RADIUS to be empty. Shutting down anyway.\n");
                return 0;
index d362e21..bc6938f 100644 (file)